@@ -26,7 +26,6 @@
  * demonstrates how to handle NV-CONTROL events.
  */
 
-
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
@@ -80,8 +79,6 @@ int main(int argc, char **argv)
         { .type = NV_CTRL_TARGET_TYPE_GPU },
         { .type = NV_CTRL_TARGET_TYPE_DISPLAY },
         { .type = NV_CTRL_TARGET_TYPE_FRAMELOCK },
-        { .type = NV_CTRL_TARGET_TYPE_VCSC },
-        { .type = NV_CTRL_TARGET_TYPE_GVI },
         { .type = NV_CTRL_TARGET_TYPE_COOLER },
         { .type = NV_CTRL_TARGET_TYPE_THERMAL_SENSOR },
         { .type = NV_CTRL_TARGET_TYPE_3D_VISION_PRO_TRANSCEIVER },
@@ -426,10 +423,6 @@ static const char *target2str(int n)
         return "Display";
     case NV_CTRL_TARGET_TYPE_FRAMELOCK:
         return "Frame Lock";
-    case NV_CTRL_TARGET_TYPE_VCSC:
-        return "VCS";
-    case NV_CTRL_TARGET_TYPE_GVI:
-        return "GVI";
     case NV_CTRL_TARGET_TYPE_COOLER:
         return "Cooler";
     case NV_CTRL_TARGET_TYPE_THERMAL_SENSOR:
@@ -509,7 +502,6 @@ static AttrEntry attr_table[] = {
     MAKE_ENTRY(NV_CTRL_CONNECTED_DISPLAYS),
     MAKE_ENTRY(NV_CTRL_ENABLED_DISPLAYS),
     MAKE_ENTRY(NV_CTRL_FRAMELOCK),
-    MAKE_ENTRY(NV_CTRL_FRAMELOCK_MASTER),
     MAKE_ENTRY(NV_CTRL_FRAMELOCK_POLARITY),
     MAKE_ENTRY(NV_CTRL_FRAMELOCK_SYNC_DELAY),
     MAKE_ENTRY(NV_CTRL_FRAMELOCK_SYNC_INTERVAL),
@@ -546,24 +538,6 @@ static AttrEntry attr_table[] = {
     MAKE_ENTRY(NV_CTRL_AMBIENT_TEMPERATURE),
     MAKE_ENTRY(NV_CTRL_PBUFFER_SCANOUT_SUPPORTED),
     MAKE_ENTRY(NV_CTRL_PBUFFER_SCANOUT_XID),
-    MAKE_ENTRY(NV_CTRL_GVO_SUPPORTED),
-    MAKE_ENTRY(NV_CTRL_GVO_SYNC_MODE),
-    MAKE_ENTRY(NV_CTRL_GVO_SYNC_SOURCE),
-    MAKE_ENTRY(NV_CTRL_GVIO_REQUESTED_VIDEO_FORMAT),
-    MAKE_ENTRY(NV_CTRL_GVIO_DETECTED_VIDEO_FORMAT),
-    MAKE_ENTRY(NV_CTRL_GVO_DATA_FORMAT),
-    MAKE_ENTRY(NV_CTRL_GVO_COMPOSITE_SYNC_INPUT_DETECTED),
-    MAKE_ENTRY(NV_CTRL_GVO_COMPOSITE_SYNC_INPUT_DETECT_MODE),
-    MAKE_ENTRY(NV_CTRL_GVO_SDI_SYNC_INPUT_DETECTED),
-    MAKE_ENTRY(NV_CTRL_GVO_VIDEO_OUTPUTS),
-    MAKE_ENTRY(NV_CTRL_GVO_FIRMWARE_VERSION),
-    MAKE_ENTRY(NV_CTRL_GVO_SYNC_DELAY_PIXELS),
-    MAKE_ENTRY(NV_CTRL_GVO_SYNC_DELAY_LINES),
-    MAKE_ENTRY(NV_CTRL_GVO_INPUT_VIDEO_FORMAT_REACQUIRE),
-    MAKE_ENTRY(NV_CTRL_GVO_GLX_LOCKED),
-    MAKE_ENTRY(NV_CTRL_GVIO_VIDEO_FORMAT_WIDTH),
-    MAKE_ENTRY(NV_CTRL_GVIO_VIDEO_FORMAT_HEIGHT),
-    MAKE_ENTRY(NV_CTRL_GVIO_VIDEO_FORMAT_REFRESH_RATE),
     MAKE_ENTRY(NV_CTRL_GPU_CURRENT_CLOCK_FREQS),
     MAKE_ENTRY(NV_CTRL_FLATPANEL_CHIP_LOCATION),
     MAKE_ENTRY(NV_CTRL_FLATPANEL_LINK),
@@ -575,18 +549,10 @@ static AttrEntry attr_table[] = {
     MAKE_ENTRY(NV_CTRL_XINERAMA),
     MAKE_ENTRY(NV_CTRL_XINERAMA_STEREO),
     MAKE_ENTRY(NV_CTRL_BUS_RATE),
-    MAKE_ENTRY(NV_CTRL_SHOW_SLI_VISUAL_INDICATOR),
     MAKE_ENTRY(NV_CTRL_XV_SYNC_TO_DISPLAY),
-    MAKE_ENTRY(NV_CTRL_GVIO_REQUESTED_VIDEO_FORMAT2),
-    MAKE_ENTRY(NV_CTRL_GVO_OVERRIDE_HW_CSC),
-    MAKE_ENTRY(NV_CTRL_GVO_CAPABILITIES),
-    MAKE_ENTRY(NV_CTRL_GVO_COMPOSITE_TERMINATION),
     MAKE_ENTRY(NV_CTRL_ASSOCIATED_DISPLAY_DEVICES),
-    MAKE_ENTRY(NV_CTRL_FRAMELOCK_SLAVES),
-    MAKE_ENTRY(NV_CTRL_FRAMELOCK_MASTERABLE),
     MAKE_ENTRY(NV_CTRL_PROBE_DISPLAYS),
     MAKE_ENTRY(NV_CTRL_REFRESH_RATE),
-    MAKE_ENTRY(NV_CTRL_GVO_FLIP_QUEUE_SIZE),
     MAKE_ENTRY(NV_CTRL_CURRENT_SCANLINE),
     MAKE_ENTRY(NV_CTRL_INITIAL_PIXMAP_PLACEMENT),
     MAKE_ENTRY(NV_CTRL_PCI_BUS),
@@ -600,7 +566,6 @@ static AttrEntry attr_table[] = {
     MAKE_ENTRY(NV_CTRL_MULTIGPU_DISPLAY_OWNER),
     MAKE_ENTRY(NV_CTRL_FSAA_APPLICATION_ENHANCED),
     MAKE_ENTRY(NV_CTRL_FRAMELOCK_SYNC_RATE_4),
-    MAKE_ENTRY(NV_CTRL_GVO_LOCK_OWNER),
     MAKE_ENTRY(NV_CTRL_HWOVERLAY),
     MAKE_ENTRY(NV_CTRL_NUM_GPU_ERRORS_RECOVERED),
     MAKE_ENTRY(NV_CTRL_REFRESH_RATE_3),
@@ -609,49 +574,22 @@ static AttrEntry attr_table[] = {
     MAKE_ENTRY(NV_CTRL_GLYPH_CACHE),
     MAKE_ENTRY(NV_CTRL_GPU_CURRENT_PERFORMANCE_LEVEL),
     MAKE_ENTRY(NV_CTRL_GPU_ADAPTIVE_CLOCK_STATE),
-    MAKE_ENTRY(NV_CTRL_GVO_OUTPUT_VIDEO_LOCKED),
-    MAKE_ENTRY(NV_CTRL_GVO_SYNC_LOCK_STATUS),
-    MAKE_ENTRY(NV_CTRL_GVO_ANC_TIME_CODE_GENERATION),
-    MAKE_ENTRY(NV_CTRL_GVO_COMPOSITE),
-    MAKE_ENTRY(NV_CTRL_GVO_COMPOSITE_ALPHA_KEY),
-    MAKE_ENTRY(NV_CTRL_GVO_COMPOSITE_LUMA_KEY_RANGE),
-    MAKE_ENTRY(NV_CTRL_GVO_COMPOSITE_CR_KEY_RANGE),
-    MAKE_ENTRY(NV_CTRL_GVO_COMPOSITE_CB_KEY_RANGE),
-    MAKE_ENTRY(NV_CTRL_GVO_COMPOSITE_NUM_KEY_RANGES),
     MAKE_ENTRY(NV_CTRL_SWITCH_TO_DISPLAYS),
     MAKE_ENTRY(NV_CTRL_NOTEBOOK_DISPLAY_CHANGE_LID_EVENT),
     MAKE_ENTRY(NV_CTRL_NOTEBOOK_INTERNAL_LCD),
     MAKE_ENTRY(NV_CTRL_DEPTH_30_ALLOWED),
     MAKE_ENTRY(NV_CTRL_MODE_SET_EVENT),
     MAKE_ENTRY(NV_CTRL_OPENGL_AA_LINE_GAMMA_VALUE),
-    MAKE_ENTRY(NV_CTRL_VCSC_HIGH_PERF_MODE),
     MAKE_ENTRY(NV_CTRL_DISPLAYPORT_LINK_RATE),
     MAKE_ENTRY(NV_CTRL_STEREO_EYES_EXCHANGE),
     MAKE_ENTRY(NV_CTRL_NO_SCANOUT),
-    MAKE_ENTRY(NV_CTRL_GVO_CSC_CHANGED_EVENT),
-    MAKE_ENTRY(NV_CTRL_FRAMELOCK_SLAVEABLE ),
-    MAKE_ENTRY(NV_CTRL_GVO_SYNC_TO_DISPLAY),
     MAKE_ENTRY(NV_CTRL_X_SERVER_UNIQUE_ID),
     MAKE_ENTRY(NV_CTRL_PIXMAP_CACHE),
     MAKE_ENTRY(NV_CTRL_PIXMAP_CACHE_ROUNDING_SIZE_KB),
-    MAKE_ENTRY(NV_CTRL_IS_GVO_DISPLAY),
     MAKE_ENTRY(NV_CTRL_PCI_ID),
-    MAKE_ENTRY(NV_CTRL_GVO_FULL_RANGE_COLOR),
     MAKE_ENTRY(NV_CTRL_SLI_MOSAIC_MODE_AVAILABLE),
-    MAKE_ENTRY(NV_CTRL_GVO_ENABLE_RGB_DATA),
     MAKE_ENTRY(NV_CTRL_IMAGE_SHARPENING_DEFAULT),
     MAKE_ENTRY(NV_CTRL_PCI_DOMAIN),
-    MAKE_ENTRY(NV_CTRL_GVI_NUM_JACKS),
-    MAKE_ENTRY(NV_CTRL_GVI_MAX_LINKS_PER_STREAM),
-    MAKE_ENTRY(NV_CTRL_GVI_DETECTED_CHANNEL_BITS_PER_COMPONENT),
-    MAKE_ENTRY(NV_CTRL_GVI_REQUESTED_STREAM_BITS_PER_COMPONENT),
-    MAKE_ENTRY(NV_CTRL_GVI_DETECTED_CHANNEL_COMPONENT_SAMPLING),
-    MAKE_ENTRY(NV_CTRL_GVI_REQUESTED_STREAM_COMPONENT_SAMPLING),
-    MAKE_ENTRY(NV_CTRL_GVI_REQUESTED_STREAM_CHROMA_EXPAND),
-    MAKE_ENTRY(NV_CTRL_GVI_DETECTED_CHANNEL_COLOR_SPACE),
-    MAKE_ENTRY(NV_CTRL_GVI_DETECTED_CHANNEL_LINK_ID),
-    MAKE_ENTRY(NV_CTRL_GVI_DETECTED_CHANNEL_SMPTE352_IDENTIFIER),
-    MAKE_ENTRY(NV_CTRL_GVI_GLOBAL_IDENTIFIER),
     MAKE_ENTRY(NV_CTRL_FRAMELOCK_SYNC_DELAY_RESOLUTION),
     MAKE_ENTRY(NV_CTRL_GPU_COOLER_MANUAL_CONTROL),
     MAKE_ENTRY(NV_CTRL_THERMAL_COOLER_LEVEL),
@@ -669,18 +607,11 @@ static AttrEntry attr_table[] = {
     MAKE_ENTRY(NV_CTRL_GPU_ECC_AGGREGATE_DOUBLE_BIT_ERRORS),
     MAKE_ENTRY(NV_CTRL_GPU_ECC_RESET_ERROR_STATUS),
     MAKE_ENTRY(NV_CTRL_GPU_POWER_MIZER_MODE),
-    MAKE_ENTRY(NV_CTRL_GVI_SYNC_OUTPUT_FORMAT),
-    MAKE_ENTRY(NV_CTRL_GVI_MAX_CHANNELS_PER_JACK),
-    MAKE_ENTRY(NV_CTRL_GVI_MAX_STREAMS ),
-    MAKE_ENTRY(NV_CTRL_GVI_NUM_CAPTURE_SURFACES),
     MAKE_ENTRY(NV_CTRL_OVERSCAN_COMPENSATION),
     MAKE_ENTRY(NV_CTRL_GPU_PCIE_GENERATION),
-    MAKE_ENTRY(NV_CTRL_GVI_BOUND_GPU),
-    MAKE_ENTRY(NV_CTRL_GVIO_REQUESTED_VIDEO_FORMAT3),
     MAKE_ENTRY(NV_CTRL_ACCELERATE_TRAPEZOIDS),
     MAKE_ENTRY(NV_CTRL_GPU_CORES),
     MAKE_ENTRY(NV_CTRL_GPU_MEMORY_BUS_WIDTH),
-    MAKE_ENTRY(NV_CTRL_GVI_TEST_MODE),
     MAKE_ENTRY(NV_CTRL_COLOR_SPACE),
     MAKE_ENTRY(NV_CTRL_COLOR_RANGE),
     MAKE_ENTRY(NV_CTRL_SHOW_VRR_VISUAL_INDICATOR),
@@ -692,9 +623,7 @@ static AttrEntry attr_table[] = {
     MAKE_ENTRY(NV_CTRL_THERMAL_SENSOR_READING),
     MAKE_ENTRY(NV_CTRL_THERMAL_SENSOR_PROVIDER),
     MAKE_ENTRY(NV_CTRL_THERMAL_SENSOR_TARGET),
-    MAKE_ENTRY(NV_CTRL_SHOW_MULTIGPU_VISUAL_INDICATOR),
     MAKE_ENTRY(NV_CTRL_GPU_CURRENT_PROCESSOR_CLOCK_FREQS),
-    MAKE_ENTRY(NV_CTRL_GVIO_VIDEO_FORMAT_FLAGS),
     MAKE_ENTRY(NV_CTRL_GPU_PCIE_MAX_LINK_SPEED),
     MAKE_ENTRY(NV_CTRL_3D_VISION_PRO_RESET_TRANSCEIVER_TO_FACTORY_SETTINGS),
     MAKE_ENTRY(NV_CTRL_3D_VISION_PRO_TRANSCEIVER_CHANNEL),
@@ -713,12 +642,10 @@ static AttrEntry attr_table[] = {
     MAKE_ENTRY(NV_CTRL_3D_VISION_PRO_GLASSES_MISSED_SYNC_CYCLES),
     MAKE_ENTRY(NV_CTRL_3D_VISION_PRO_GLASSES_BATTERY_LEVEL),
     MAKE_ENTRY(NV_CTRL_3D_VISION_PRO_GLASSES_BATTERY_LEVEL),
-    MAKE_ENTRY(NV_CTRL_GVO_ANC_PARITY_COMPUTATION),
     MAKE_ENTRY(NV_CTRL_3D_VISION_PRO_GLASSES_PAIR_EVENT),
     MAKE_ENTRY(NV_CTRL_3D_VISION_PRO_GLASSES_UNPAIR_EVENT),
     MAKE_ENTRY(NV_CTRL_GPU_PCIE_CURRENT_LINK_WIDTH),
     MAKE_ENTRY(NV_CTRL_GPU_PCIE_CURRENT_LINK_SPEED),
-    MAKE_ENTRY(NV_CTRL_GVO_AUDIO_BLANKING),
     MAKE_ENTRY(NV_CTRL_CURRENT_METAMODE_ID),
     MAKE_ENTRY(NV_CTRL_DISPLAY_ENABLED),
     MAKE_ENTRY(NV_CTRL_FRAMELOCK_INCOMING_HOUSE_SYNC_RATE),
@@ -731,7 +658,7 @@ static AttrEntry attr_table[] = {
     MAKE_ENTRY(NV_CTRL_GPU_DOUBLE_PRECISION_BOOST_REBOOT),
     MAKE_ENTRY(NV_CTRL_DPY_HDMI_3D),
     MAKE_ENTRY(NV_CTRL_BASE_MOSAIC),
-    MAKE_ENTRY(NV_CTRL_MULTIGPU_MASTER_POSSIBLE),
+    MAKE_ENTRY(NV_CTRL_MULTIGPU_PRIMARY_POSSIBLE),
     MAKE_ENTRY(NV_CTRL_GPU_POWER_MIZER_DEFAULT_MODE),
     MAKE_ENTRY(NV_CTRL_XV_SYNC_TO_DISPLAY_ID),
     MAKE_ENTRY(NV_CTRL_CURRENT_XV_SYNC_TO_DISPLAY_ID),
