@@ -1,20 +1,23 @@
 /*
  * Copyright (C) 2004-2010 NVIDIA Corporation
  *
- * This program is free software; you can redistribute it and/or modify it
- * under the terms and conditions of the GNU General Public License,
- * version 2, as published by the Free Software Foundation.
+ * Permission is hereby granted, free of charge, to any person obtaining a
+ * copy of this software and associated documentation files (the "Software"),
+ * to deal in the Software without restriction, including without limitation
+ * the rights to use, copy, modify, merge, publish, distribute, sublicense,
+ * and/or sell copies of the Software, and to permit persons to whom the
+ * Software is furnished to do so, subject to the following conditions:
  *
- * This program is distributed in the hope that it will be useful, but WITHOUT
- * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
- * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
- * more details.
+ * The above copyright notice and this permission notice shall be included in
+ * all copies or substantial portions of the Software.
  *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, see <http://www.gnu.org/licenses>.
- *
- *
- * nvgetopt.h
+ * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
+ * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
+ * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.  IN NO EVENT SHALL
+ * THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
+ * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
+ * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
+ * DEALINGS IN THE SOFTWARE.
  */
 
 #ifndef __NVGETOPT_H__
@@ -34,8 +37,8 @@
 
 /*
  * indicates that the option is a boolean value; the presence of the
- * option will be interpretted as a TRUE value; if the option is
- * prepended with '--no-', the option will be interpretted as a FALSE
+ * option will be interpreted as a TRUE value; if the option is
+ * prepended with '--no-', the option will be interpreted as a FALSE
  * value.  On success, nvgetopt will return the parsed boolean value
  * through 'boolval'.
  */
@@ -114,8 +117,8 @@ typedef struct {
     const char *name;
     int val;
     unsigned int flags;
-    char *arg_name;     /* not used by nvgetopt() */
-    char *description;  /* not used by nvgetopt() */
+    const char *arg_name;     /* not used by nvgetopt() */
+    const char *description;  /* not used by nvgetopt() */
 } NVGetoptOption;
 
 
@@ -163,7 +166,7 @@ int nvgetopt(int argc,
  * Options will only be printed if they have every bit set that
  * include_mask includes.
  *
- * For each option, the provided callback function wil be called with
+ * For each option, the provided callback function will be called with
  * two strings: a name string that lists the option's name, and a
  * description string for the option.  The callback function is
  * responsible for actually printing these strings.  Examples:
